Learn R Programming

M3JF (version 0.1.0)

iNMF_data_gen: Generate the simulated dataset with three modalities as the work iNMF

Description

Generate the simulated dataset with three modalities as the work iNMF

Usage

iNMF_data_gen(Xs_dim_list=list(c(100,100),c(100,100),c(100,100)),
mod_dim_list=list(matrix(c(20,30,20,30,20,30,20,30),4,2),
matrix(c(20,20,30,30,20,30,20,30),4,2),
matrix(c(26,24,26,24,20,30,20,30),4,2)),e_u=0.15, e_s=0.9, e_h=0)

Value

res, a list of length 2, where the first element is a list of simulated data, while the second element is a vector indicating the true label of each sample.

Arguments

Xs_dim_list

a list of data matrix dimensions for multiple modality data

mod_dim_list

a list of the dimensions of each cluster and their features

e_u

the level of uniform noise

e_s

signal to noise ratio

e_h

block adding probability

Examples

Run this code
iNMF_data <- iNMF_data_gen(Xs_dim_list=list(c(100,100),c(100,100),c(100,100)),
mod_dim_list=list(matrix(c(20,30,20,30,20,30,20,30),4,2),
matrix(c(20,20,30,30,20,30,20,30),4,2),
matrix(c(26,24,26,24,20,30,20,30),4,2)),e_u=0.15, e_s=0.9, e_h=0)

Run the code above in your browser using DataLab